summaryrefslogtreecommitdiffstats
path: root/include/clang/Rewrite/Rewriter.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/clang/Rewrite/Rewriter.h')
-rw-r--r--include/clang/Rewrite/Rewriter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/clang/Rewrite/Rewriter.h b/include/clang/Rewrite/Rewriter.h
index 29e78fa..1692180 100644
--- a/include/clang/Rewrite/Rewriter.h
+++ b/include/clang/Rewrite/Rewriter.h
@@ -146,13 +146,13 @@ public:
/// are in the same file. If not, this returns -1.
int getRangeSize(SourceRange Range) const;
/// getRewritenText - Return the rewritten form of the text in the specified
/// range. If the start or end of the range was unrewritable or if they are
/// in different buffers, this returns an empty string.
///
/// Note that this method is not particularly efficient.
///
- std::string getRewritenText(SourceRange Range) const;
+ std::string getRewrittenText(SourceRange Range) const;
/// InsertText - Insert the specified string at the specified location in the
/// original buffer. This method returns true (and does nothing) if the input
OpenPOWER on IntegriCloud
@@ -146,13 +146,13 @@ public:
/// are in the same file. If not, this returns -1.
int getRangeSize(SourceRange Range) const;
- /// getRewritenText - Return the rewritten form of the text in the specified
+ /// getRewrittenText - Return the rewritten form of the text in the specified
/// range. If the start or end of the range was unrewritable or if they are
/// in different buffers, this returns an empty string.